@@ -450,12 +450,12 @@ setAs("GAlignmentPairs", "GAlignments",
 
 
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-### fillGaps()
+### fillJunctionGaps()
 ###
 ### Not exported. Used in the SplicingGraphs package.
 ###
 
-fillGaps <- function(x)
+fillJunctionGaps <- function(x)
 {
     if (!is(x, "GRangesList"))
         stop("'x' must be a GRangesList object")
@@ -542,7 +542,10 @@ showGAlignmentPairs <- function(x, margin="",
     }
     if (nrow(out) != 0L)
         rownames(out) <- paste0(margin, rownames(out))
-    print(out, quote=FALSE, right=TRUE)
+    ## We set 'max' to 'length(out)' to avoid the getOption("max.print")
+    ## limit that would typically be reached when 'showHeadLines' global
+    ## option is set to Inf.
+    print(out, quote=FALSE, right=TRUE, max=length(out))
     if (print.seqlengths) {
         cat(margin, "---\n", sep="")
         GenomicRanges:::showSeqlengths(x, margin=margin)
